wellformednesstools.MissingParentCheck
======================================

.. abjad-lineage:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck

.. autoclass:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.check
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.report
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.violators
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__eq__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__ge__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__gt__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__le__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__lt__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__ne__
   :noindex:

.. automethod:: abjad.tools.wellformednesstools.MissingParentCheck.MissingParentCheck.MissingParentCheck.__repr__
   :noindex:
